==> nextcloud-26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/eo.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privateco",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "La privatecejo montras, kie viaj datumoj konserviĝas, kaj kiu povas aliri al ili, ĉar vi kunhavigis kun ili aŭ ili estas administrantoj.",
    "Add external admin" : "Aldoni eksteran administranton",
    "This server is using full-disk-encryption." : "Tiu servilo uzas ĉifradon de la tuta disko.",
    "This server is protected with full-disk-encryption." : "Tiu servilo estas protektita per ĉifrado de la tuta disko.",
    "Your files are not protected by encryption." : "Viaj dosieroj ne estas protektitaj per ĉifrado.",
    "Change data location" : "Ŝanĝi la lokon de la datumoj",
    "You don't have any shares with individual users." : "Vi havas neniun kunhavon kun individuaj uzantoj.",
    "Somaliland" : "Somalujo",
    "Andorra" : "Andoro",
    "United Arab Emirates" : "Unuiĝintaj Arabaj Emirlandoj",
    "Afghanistan" : "Afganujo",
    "Antigua and Barbuda" : "Antigvo kaj Barbudo",
    "Anguilla" : "Angvilo",
    "Albania" : "Albanujo",
    "Armenia" : "Armenujo",
    "Angola" : "Angolo",
    "Antarctica" : "Antarkto",
    "Argentina" : "Argentino",
    "American Samoa" : "Usona Samoo",
    "Austria" : "Aŭstrujo",
    "Australia" : "Aŭstralio",
    "Aruba" : "Arubo",
    "Åland Islands" : "Alando",
    "Azerbaijan" : "Azerbajĝano",
    "Bosnia and Herzegovina" : "Bosnujo kaj Hercegovino",
    "Barbados" : "Barbado",
    "Bangladesh" : "Bangladeŝo",
    "Belgium" : "Belgujo",
    "Burkina Faso" : "Burkino",
    "Bulgaria" : "Bulgarujo",
    "Bahrain" : "Barejno",
    "Burundi" : "Burundo",
    "Benin" : "Benino",
    "Saint Barthélemy" : "Sankta Bartolomeo",
    "Bermuda" : "Bermudoj",
    "Brunei" : "Brunejo",
    "Bolivia" : "Bolivio",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius kaj Saba",
    "Brazil" : "Brazilo",
    "Bahamas" : "Bahamoj",
    "Bhutan" : "Butano",
    "Bouvet Island" : "Buvetinsulo",
    "Botswana" : "Bocvano",
    "Belarus" : "Belorusujo",
    "Belize" : "Belizo",
    "Canada" : "Kanado",
    "Cocos (Keeling) Islands" : "Kokosinsuloj",
    "Democratic Republic of the Congo" : "Kongo (Kinŝasa)",
    "Central African Republic" : "Centr-Afriko",
    "Congo" : "Kongo (Brazavila)",
    "Switzerland" : "Svislando",
    "Cote d'Ivoire" : "Ebur-Bordo",
    "Cook Islands" : "Kukinsuloj",
    "Chile" : "Ĉilio",
    "Cameroon" : "Kameruno",
    "China" : "Ĉinujo",
    "Colombia" : "Kolombio",
    "Costa Rica" : "Kostariko",
    "Cuba" : "Kubo",
    "Cabo Verde" : "Kaboverdo",
    "Curaçao" : "Kuracao",
    "Christmas Island" : "Kristnaskinsulo",
    "Cyprus" : "Kipro",
    "Czech" : "Ĉeĥujo",
    "Germany" : "Germanujo",
    "Djibouti" : "Ĝibutio",
    "Denmark" : "Danujo",
    "Dominican Republic" : "Dominika Respubliko",
    "Algeria" : "Alĝerio",
    "Ecuador" : "Ekvadoro",
    "Estonia" : "Estonujo",
    "Egypt" : "Egiptujo",
    "West Sahara" : "Okcidenta Saharo",
    "Eritrea" : "Eritreo",
    "Spain" : "Hispanujo",
    "Ethiopia" : "Etiopujo",
    "Finland" : "Finnlando",
    "Fiji" : "Fiĝio",
    "Falkland Islands" : "Falklandoj",
    "Faroe Islands" : "Ferooj",
    "France" : "Francujo",
    "Gabon" : "Gabono",
    "United Kingdom" : "Unuiĝinta Reĝlando",
    "Grenada" : "Grenado",
    "Georgia" : "Kartvelujo",
    "French Guiana" : "Franca Gviano",
    "Guernsey" : "Gernezejo",
    "Ghana" : "Ganao",
    "Gibraltar" : "Ĝibraltaro",
    "Greenland" : "Gronlando",
    "Gambia" : "Gambio",
    "Guinea" : "Gvineo",
    "Guadeloupe" : "Gvadelupo",
    "Equatorial Guinea" : "Ekvatora Gvineo",
    "Greece" : "Grekujo",
    "South Georgia and the South Sandwich Islands" : "Sud-Georgio kaj Sud-Sandviĉinsuloj",
    "Guatemala" : "Gvatemalo",
    "Guam" : "Gvamo",
    "Guinea-Bissau" : "Gvineo-Bisaŭo",
    "Guyana" : "Gujano",
    "Honduras" : "Honduro",
    "Hong Kong" : "Honkongo",
    "Heard Island and McDonald Islands" : "Herda kaj Makdonaldaj Insuloj",
    "Croatia" : "Kroatujo",
    "Haiti" : "Haitio",
    "Hungary" : "Hungarujo",
    "Indonesia" : "Indonezio",
    "Ireland" : "Irlando",
    "Israel" : "Israelo",
    "Isle of Man" : "Manksinsulo",
    "India" : "Barato",
    "British Indian Ocean Territory" : "Brita Hindoceana Teritorio",
    "Iraq" : "Irako",
    "Iran" : "Irano",
    "Iceland" : "Islando",
    "Italy" : "Italujo",
    "Jamaica" : "Jamajko",
    "Jordan" : "Jordanio",
    "Japan" : "Japanujo",
    "Kenya" : "Kenjo",
    "Kyrgyzstan" : "Kirgizujo",
    "Cambodia" : "Kamboĝo",
    "Kiribati" : "Kiribato",
    "Saint Kitts and Nevis" : "Sankta Kristoforo kaj Neviso",
    "North Korea" : "Nord-Koreujo",
    "South Korea" : "Sud-Koreujo",
    "Kuwait" : "Kuvajto",
    "Cayman Islands" : "Kejmanoj",
    "Kazakhstan" : "Kazaĥujo",
    "Laos" : "Laoso",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Sankta Lucio",
    "Liechtenstein" : "Liĥtenŝtejno",
    "Sri Lanka" : "Srilanko",
    "Liberia" : "Liberio",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litovujo",
    "Luxembourg" : "Luksemburgo",
    "Latvia" : "Latvujo",
    "Libya" : "Libio",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavujo",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskaro",
    "Marshall Islands" : "Marŝaloj",
    "Macedonia" : "Makedonujo",
    "Mali" : "Malio",
    "Myanmar" : "Birmo",
    "Mongolia" : "Mongolujo",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Nord-Marianoj",
    "Mauritania" : "Maŭritanio",
    "Montserrat" : "Moncerato",
    "Malta" : "Malto",
    "Mauritius" : "Maŭricio",
    "Maldives" : "Maldivoj",
    "Malawi" : "Malavio",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malajzio",
    "Mozambique" : "Mozambiko",
    "Namibia" : "Namibio",
    "New Caledonia" : "Nov-Kaledonio",
    "Niger" : "Niĝero",
    "Norfolk Island" : "Norfolkinsulo",
    "Nigeria" : "Niĝerio",
    "Nicaragua" : "Nikaragvo",
    "Netherlands" : "Nederlando",
    "Norway" : "Norvegujo",
    "Nepal" : "Nepalo",
    "Nauru" : "Nauro",
    "Niue" : "Niuo",
    "New Zealand" : "Nov-Zelando",
    "Oman" : "Omano",
    "Panama" : "Panamo",
    "Peru" : "Peruo",
    "French Polynesia" : "Franca Polinezio",
    "Papua New Guinea" : "Papuo-Nov-Gvineo",
    "Philippines" : "Filipinoj",
    "Pakistan" : "Pakistano",
    "Poland" : "Pollando",
    "Saint Pierre and Miquelon" : "Sankta Piero kaj Mikelono",
    "Pitcairn" : "Pitkarna Insulo",
    "Puerto Rico" : "Puertoriko",
    "Portugal" : "Portugalujo",
    "Palau" : "Palaŭo",
    "Paraguay" : "Paragvajo",
    "Qatar" : "Kataro",
    "Réunion" : "Reunio",
    "Romania" : "Rumanujo",
    "Serbia" : "Serbujo",
    "Russia" : "Rusujo",
    "Rwanda" : "Ruando",
    "Saudi Arabia" : "Sauda Arabujo",
    "Solomon Islands" : "Salomonoj",
    "Seychelles" : "Sejŝeloj",
    "Sudan" : "Sudano",
    "Sweden" : "Svedujo",
    "Singapore" : "Singapuro",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankta Heleno, Ascension kaj Tristan da Cunha",
    "Slovenia" : "Slovenujo",
    "Svalbard and Jan Mayen" : "Svalbardo",
    "Slovakia" : "Slovakujo",
    "Sierra Leone" : "Sieraleono",
    "San Marino" : "Sanmarino",
    "Senegal" : "Senegalo",
    "Somalia" : "Somalujo",
    "Suriname" : "Surinamo",
    "South Sudan" : "Sud-Sudano",
    "Sao Tome and Principe" : "Santomeo kaj Principeo",
    "El Salvador" : "Salvadoro",
    "Syria" : "Sirio",
    "Swaziland" : "Svazilando",
    "Turks and Caicos Islands" : "Turkoj kaj Kajkoj",
    "Chad" : "Ĉado",
    "Fr. S. Antarctic Lands" : "Francaj sudaj kaj antarktaj teritorioj",
    "Togo" : "Togolando",
    "Thailand" : "Tajlando",
    "Tajikistan" : "Taĝikujo",
    "Tokelau" : "Tokelao",
    "Timor-Leste" : "Orienta Timoro",
    "Turkmenistan" : "Turkmenujo",
    "Tunisia" : "Tunizio",
    "Tonga" : "Tonga",
    "Turkey" : "Turkujo",
    "Trinidad and Tobago" : "Trinidado kaj Tobago",
    "Tuvalu" : "Tuvalo",
    "Taiwan" : "Tajvano",
    "Tanzania" : "Tanzanio",
    "Ukraine" : "Ukrainujo",
    "Uganda" : "Ugando",
    "United States Minor Outlying Islands" : "Usonaj Malgrandaj Insuloj",
    "United States" : "Usono",
    "Uruguay" : "Urugvajo",
    "Uzbekistan" : "Uzbekujo",
    "Holy See" : "Sankta Seĝo",
    "Saint Vincent and the Grenadines" : "Sankta Vincento kaj Grenadinoj",
    "Venezuela" : "Venezuelo",
    "Virgin Islands (British)" : "Britaj Virgulininsuloj",
    "Virgin Islands (U.S.)" : "Usonaj Virgulininsuloj",
    "Vietnam" : "Vjetnamujo",
    "Vanuatu" : "Vanuatuo",
    "Wallis and Futuna" : "Valiso kaj Futuno",
    "Samoa" : "Samoo",
    "Yemen" : "Jemeno",
    "Mayotte" : "Majoto",
    "South Africa" : "Sud-Afriko",
    "Zambia" : "Zambio",
    "Zimbabwe" : "Zimbabvo",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Viaj datumoj reprezentas tiun, kiu vi estas, kaj ili povas facile esti misuzitaj. Ni ĉe Nextcloud opinias, ke vi rajtas decidi tion, kio okazas kun viaj datumoj. Nextcloud protektas viajn rajtojn difinitaj en la Proklamo pri uzantodatumoj!",
    "User Data Manifesto 2.0" : "Proklamo pri uzantodatumoj 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Difini bazajn homajn rajtojn por regi siajn datumojn en la interreta epoko",
    "Control" : "Kontrolo",
    "over user data access" : "super aliro al la uzantodatumoj",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Datumoj klare kaj vole alŝutitaj de uzanto devas esti sub plena kontrolo de la uzanto. Uzantoj devas povi decidi, al kiu doni aliron al siaj datumoj kaj kun kiu permeso kaj permesilo.",
    "Knowledge" : "Scio",
    "of how the data is stored" : "pri kiel oni konservas  la datumojn",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiam la datumoj alŝutiĝas al specifa servoprovizanto, uzantoj devas sciiĝi pri la loko de konservo de la datumoj, pri la daŭro, pri la jurisdikcio, kie la provizanto agas, kaj kiuj leĝoj aplikiĝas.",
    "Freedom" : "Libero",
    "to choose a platform" : "elekti platformon",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Uzantoj devas ĉiam povi elpreni siajn datumojn el la servo iam ajn sen vendisto-dependiĝo. Malfermaj normoj pri datumaranĝoj kaj protokoloj necesas, por ke tio eblu.",
    "Learn more ↗" : "Scii pli ↗",
    "Where is your data?" : "Kie estas viaj datumoj?",
    "Who has access to your data?" : "Kiu povas aliri al viaj datumoj?",
    "Administrators" : "Administrantoj",
    "People you shared with" : "Homoj, kun kiuj vi kunhavigis ion",
    "Privacy policy" : "Privateca regularo",
    "Read the privacy policy." : "Legi la regularon pri privateco.",
    "Encryption" : "Ĉifrado",
    "Remove external admin" : "Forigi eksteran administranton"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/eo.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privateco",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "La privatecejo montras, kie viaj datumoj konserviĝas, kaj kiu povas aliri al ili, ĉar vi kunhavigis kun ili aŭ ili estas administrantoj.",
    "Administrators" : "Administrantoj",
    "Add external admin" : "Aldoni eksteran administranton",
    "Cancel" : "Cancel",
    "This server is protected with full-disk-encryption." : "Tiu servilo estas protektita per ĉifrado de la tuta disko.",
    "Your files are not protected by encryption." : "Viaj dosieroj ne estas protektitaj per ĉifrado.",
    "Encryption" : "Ĉifrado",
    "Edit" : "Modifi",
    "This server is using full-disk-encryption." : "Tiu servilo uzas ĉifradon de la tuta disko.",
    "Privacy policy" : "Privateca regularo",
    "Who has access to your data?" : "Kiu povas aliri al viaj datumoj?",
    "Where is your data?" : "Kie estas viaj datumoj?",
    "Change data location" : "Ŝanĝi la lokon de la datumoj",
    "Region" : "Regiono",
    "User Data Manifesto 2.0" : "Proklamo pri uzantodatumoj 2.0",
    "Control" : "Kontrolo",
    "over user data access" : "super aliro al la uzantodatumoj",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Datumoj klare kaj vole alŝutitaj de uzanto devas esti sub plena kontrolo de la uzanto. Uzantoj devas povi decidi, al kiu doni aliron al siaj datumoj kaj kun kiu permeso kaj permesilo.",
    "Knowledge" : "Scio",
    "of how the data is stored" : "pri kiel oni konservas  la datumojn",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiam la datumoj alŝutiĝas al specifa servoprovizanto, uzantoj devas sciiĝi pri la loko de konservo de la datumoj, pri la daŭro, pri la jurisdikcio, kie la provizanto agas, kaj kiuj leĝoj aplikiĝas.",
    "Freedom" : "Libero",
    "to choose a platform" : "elekti platformon",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Uzantoj devas ĉiam povi elpreni siajn datumojn el la servo iam ajn sen vendisto-dependiĝo. Malfermaj normoj pri datumaranĝoj kaj protokoloj necesas, por ke tio eblu.",
    "Learn more ↗" : "Scii pli ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Viaj datumoj reprezentas tiun, kiu vi estas, kaj ili povas facile esti misuzitaj. Ni ĉe Nextcloud opinias, ke vi rajtas decidi tion, kio okazas kun viaj datumoj. Nextcloud protektas viajn rajtojn difinitaj en la Proklamo pri uzantodatumoj!",
    "Somaliland" : "Somalujo",
    "Andorra" : "Andoro",
    "United Arab Emirates" : "Unuiĝintaj Arabaj Emirlandoj",
    "Afghanistan" : "Afganujo",
    "Antigua and Barbuda" : "Antigvo kaj Barbudo",
    "Anguilla" : "Angvilo",
    "Albania" : "Albanujo",
    "Armenia" : "Armenujo",
    "Angola" : "Angolo",
    "Antarctica" : "Antarkto",
    "Argentina" : "Argentino",
    "American Samoa" : "Usona Samoo",
    "Austria" : "Aŭstrujo",
    "Australia" : "Aŭstralio",
    "Aruba" : "Arubo",
    "Åland Islands" : "Alando",
    "Azerbaijan" : "Azerbajĝano",
    "Bosnia and Herzegovina" : "Bosnujo kaj Hercegovino",
    "Barbados" : "Barbado",
    "Bangladesh" : "Bangladeŝo",
    "Belgium" : "Belgujo",
    "Burkina Faso" : "Burkino",
    "Bulgaria" : "Bulgarujo",
    "Bahrain" : "Barejno",
    "Burundi" : "Burundo",
    "Benin" : "Benino",
    "Saint Barthélemy" : "Sankta Bartolomeo",
    "Bermuda" : "Bermudoj",
    "Brunei" : "Brunejo",
    "Bolivia" : "Bolivio",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius kaj Saba",
    "Brazil" : "Brazilo",
    "Bahamas" : "Bahamoj",
    "Bhutan" : "Butano",
    "Bouvet Island" : "Buvetinsulo",
    "Botswana" : "Bocvano",
    "Belarus" : "Belorusujo",
    "Belize" : "Belizo",
    "Canada" : "Kanado",
    "Cocos (Keeling) Islands" : "Kokosinsuloj",
    "Democratic Republic of the Congo" : "Kongo (Kinŝasa)",
    "Central African Republic" : "Centr-Afriko",
    "Congo" : "Kongo (Brazavila)",
    "Switzerland" : "Svislando",
    "Cote d'Ivoire" : "Ebur-Bordo",
    "Cook Islands" : "Kukinsuloj",
    "Chile" : "Ĉilio",
    "Cameroon" : "Kameruno",
    "China" : "Ĉinujo",
    "Colombia" : "Kolombio",
    "Costa Rica" : "Kostariko",
    "Cuba" : "Kubo",
    "Cabo Verde" : "Kaboverdo",
    "Curaçao" : "Kuracao",
    "Christmas Island" : "Kristnaskinsulo",
    "Cyprus" : "Kipro",
    "Czech" : "Ĉeĥujo",
    "Germany" : "Germanujo",
    "Djibouti" : "Ĝibutio",
    "Denmark" : "Danujo",
    "Dominican Republic" : "Dominika Respubliko",
    "Algeria" : "Alĝerio",
    "Ecuador" : "Ekvadoro",
    "Estonia" : "Estonujo",
    "Egypt" : "Egiptujo",
    "West Sahara" : "Okcidenta Saharo",
    "Eritrea" : "Eritreo",
    "Spain" : "Hispanujo",
    "Ethiopia" : "Etiopujo",
    "Finland" : "Finnlando",
    "Fiji" : "Fiĝio",
    "Falkland Islands" : "Falklandoj",
    "Faroe Islands" : "Ferooj",
    "France" : "Francujo",
    "Gabon" : "Gabono",
    "United Kingdom" : "Unuiĝinta Reĝlando",
    "Grenada" : "Grenado",
    "Georgia" : "Kartvelujo",
    "French Guiana" : "Franca Gviano",
    "Guernsey" : "Gernezejo",
    "Ghana" : "Ganao",
    "Gibraltar" : "Ĝibraltaro",
    "Greenland" : "Gronlando",
    "Gambia" : "Gambio",
    "Guinea" : "Gvineo",
    "Guadeloupe" : "Gvadelupo",
    "Equatorial Guinea" : "Ekvatora Gvineo",
    "Greece" : "Grekujo",
    "South Georgia and the South Sandwich Islands" : "Sud-Georgio kaj Sud-Sandviĉinsuloj",
    "Guatemala" : "Gvatemalo",
    "Guam" : "Gvamo",
    "Guinea-Bissau" : "Gvineo-Bisaŭo",
    "Guyana" : "Gujano",
    "Hong Kong" : "Honkongo",
    "Heard Island and McDonald Islands" : "Herda kaj Makdonaldaj Insuloj",
    "Honduras" : "Honduro",
    "Croatia" : "Kroatujo",
    "Haiti" : "Haitio",
    "Hungary" : "Hungarujo",
    "Indonesia" : "Indonezio",
    "Ireland" : "Irlando",
    "Israel" : "Israelo",
    "Isle of Man" : "Manksinsulo",
    "India" : "Barato",
    "British Indian Ocean Territory" : "Brita Hindoceana Teritorio",
    "Iraq" : "Irako",
    "Iran" : "Irano",
    "Iceland" : "Islando",
    "Italy" : "Italujo",
    "Jamaica" : "Jamajko",
    "Jordan" : "Jordanio",
    "Japan" : "Japanujo",
    "Kenya" : "Kenjo",
    "Kyrgyzstan" : "Kirgizujo",
    "Cambodia" : "Kamboĝo",
    "Kiribati" : "Kiribato",
    "Saint Kitts and Nevis" : "Sankta Kristoforo kaj Neviso",
    "North Korea" : "Nord-Koreujo",
    "South Korea" : "Sud-Koreujo",
    "Kuwait" : "Kuvajto",
    "Cayman Islands" : "Kejmanoj",
    "Kazakhstan" : "Kazaĥujo",
    "Laos" : "Laoso",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Sankta Lucio",
    "Liechtenstein" : "Liĥtenŝtejno",
    "Sri Lanka" : "Srilanko",
    "Liberia" : "Liberio",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litovujo",
    "Luxembourg" : "Luksemburgo",
    "Latvia" : "Latvujo",
    "Libya" : "Libio",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavujo",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskaro",
    "Marshall Islands" : "Marŝaloj",
    "Macedonia" : "Makedonujo",
    "Mali" : "Malio",
    "Myanmar" : "Birmo",
    "Mongolia" : "Mongolujo",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Nord-Marianoj",
    "Mauritania" : "Maŭritanio",
    "Montserrat" : "Moncerato",
    "Malta" : "Malto",
    "Mauritius" : "Maŭricio",
    "Maldives" : "Maldivoj",
    "Malawi" : "Malavio",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malajzio",
    "Mozambique" : "Mozambiko",
    "Namibia" : "Namibio",
    "New Caledonia" : "Nov-Kaledonio",
    "Niger" : "Niĝero",
    "Norfolk Island" : "Norfolkinsulo",
    "Nigeria" : "Niĝerio",
    "Nicaragua" : "Nikaragvo",
    "Netherlands" : "Nederlando",
    "Norway" : "Norvegujo",
    "Nepal" : "Nepalo",
    "Nauru" : "Nauro",
    "Niue" : "Niuo",
    "New Zealand" : "Nov-Zelando",
    "Oman" : "Omano",
    "Panama" : "Panamo",
    "Peru" : "Peruo",
    "French Polynesia" : "Franca Polinezio",
    "Papua New Guinea" : "Papuo-Nov-Gvineo",
    "Philippines" : "Filipinoj",
    "Pakistan" : "Pakistano",
    "Poland" : "Pollando",
    "Saint Pierre and Miquelon" : "Sankta Piero kaj Mikelono",
    "Pitcairn" : "Pitkarna Insulo",
    "Puerto Rico" : "Puertoriko",
    "Portugal" : "Portugalujo",
    "Palau" : "Palaŭo",
    "Paraguay" : "Paragvajo",
    "Qatar" : "Kataro",
    "Réunion" : "Reunio",
    "Romania" : "Rumanujo",
    "Serbia" : "Serbujo",
    "Russia" : "Rusujo",
    "Rwanda" : "Ruando",
    "Saudi Arabia" : "Sauda Arabujo",
    "Solomon Islands" : "Salomonoj",
    "Seychelles" : "Sejŝeloj",
    "Sudan" : "Sudano",
    "Sweden" : "Svedujo",
    "Singapore" : "Singapuro",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankta Heleno, Ascension kaj Tristan da Cunha",
    "Slovenia" : "Slovenujo",
    "Svalbard and Jan Mayen" : "Svalbardo",
    "Slovakia" : "Slovakujo",
    "Sierra Leone" : "Sieraleono",
    "San Marino" : "Sanmarino",
    "Senegal" : "Senegalo",
    "Somalia" : "Somalujo",
    "Suriname" : "Surinamo",
    "South Sudan" : "Sud-Sudano",
    "Sao Tome and Principe" : "Santomeo kaj Principeo",
    "El Salvador" : "Salvadoro",
    "Syria" : "Sirio",
    "Swaziland" : "Svazilando",
    "Turks and Caicos Islands" : "Turkoj kaj Kajkoj",
    "Chad" : "Ĉado",
    "Fr. S. Antarctic Lands" : "Francaj sudaj kaj antarktaj teritorioj",
    "Togo" : "Togolando",
    "Thailand" : "Tajlando",
    "Tajikistan" : "Taĝikujo",
    "Tokelau" : "Tokelao",
    "Timor-Leste" : "Orienta Timoro",
    "Turkmenistan" : "Turkmenujo",
    "Tunisia" : "Tunizio",
    "Tonga" : "Tonga",
    "Turkey" : "Turkujo",
    "Trinidad and Tobago" : "Trinidado kaj Tobago",
    "Tuvalu" : "Tuvalo",
    "Taiwan" : "Tajvano",
    "Tanzania" : "Tanzanio",
    "Ukraine" : "Ukrainujo",
    "Uganda" : "Ugando",
    "United States Minor Outlying Islands" : "Usonaj Malgrandaj Insuloj",
    "United States" : "Usono",
    "Uruguay" : "Urugvajo",
    "Uzbekistan" : "Uzbekujo",
    "Holy See" : "Sankta Seĝo",
    "Saint Vincent and the Grenadines" : "Sankta Vincento kaj Grenadinoj",
    "Venezuela" : "Venezuelo",
    "Virgin Islands (British)" : "Britaj Virgulininsuloj",
    "Virgin Islands (U.S.)" : "Usonaj Virgulininsuloj",
    "Vietnam" : "Vjetnamujo",
    "Vanuatu" : "Vanuatuo",
    "Wallis and Futuna" : "Valiso kaj Futuno",
    "Samoa" : "Samoo",
    "Yemen" : "Jemeno",
    "Mayotte" : "Majoto",
    "South Africa" : "Sud-Afriko",
    "Zambia" : "Zambio",
    "Zimbabwe" : "Zimbabvo"
},
"nplurals=2; plural=(n != 1);");
